==> binutils_2.24.51.20140425.orig.tar.gz: binutils-2.24.51.20140425/bfd/epoc-pe-arm.c <==
/* BFD back-end for ARM EPOC PE files.
   Copyright (C) 1999-2014 Free Software Foundation, Inc.

   This file is part of BFD, the Binary File Descriptor library.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston,
   MA 02110-1301, USA.  */

#define TARGET_UNDERSCORE    0
#define USER_LABEL_PREFIX    ""

#define TARGET_LITTLE_SYM    arm_epoc_pe_little_vec
#define TARGET_LITTLE_NAME   "epoc-pe-arm-little"
#define TARGET_BIG_SYM       arm_epoc_pe_big_vec
#define TARGET_BIG_NAME      "epoc-pe-arm-big"

#define bfd_arm_allocate_interworking_sections \
	bfd_arm_epoc_pe_allocate_interworking_sections
#define bfd_arm_get_bfd_for_interworking \
	bfd_arm_epoc_pe_get_bfd_for_interworking
#define bfd_arm_process_before_allocation \
	bfd_arm_epoc_pe_process_before_allocation

#define EXTRA_S_FLAGS (SEC_LINK_ONCE | SEC_LINK_DUPLICATES | SEC_CODE | SEC_READONLY | SEC_DATA)

#include "pe-arm.c"

==> binutils_2.25.51.20151014.orig.tar.gz: binutils-2.25.51.20151014/bfd/epoc-pe-arm.c <==
/* BFD back-end for ARM EPOC PE files.
   Copyright (C) 1999-2015 Free Software Foundation, Inc.

   This file is part of BFD, the Binary File Descriptor library.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston,
   MA 02110-1301, USA.  */

#define TARGET_UNDERSCORE    0
#define USER_LABEL_PREFIX    ""

#define TARGET_LITTLE_SYM    arm_pe_epoc_le_vec
#define TARGET_LITTLE_NAME   "epoc-pe-arm-little"
#define TARGET_BIG_SYM       arm_pe_epoc_be_vec
#define TARGET_BIG_NAME      "epoc-pe-arm-big"

#define bfd_arm_allocate_interworking_sections \
	bfd_arm_epoc_pe_allocate_interworking_sections
#define bfd_arm_get_bfd_for_interworking \
	bfd_arm_epoc_pe_get_bfd_for_interworking
#define bfd_arm_process_before_allocation \
	bfd_arm_epoc_pe_process_before_allocation

#define EXTRA_S_FLAGS (SEC_LINK_ONCE | SEC_LINK_DUPLICATES | SEC_CODE | SEC_READONLY | SEC_DATA)

#include "pe-arm.c"
